lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [lmi] master 4f10238 05/10: Rename a local variable


From: Greg Chicares
Subject: [lmi-commits] [lmi] master 4f10238 05/10: Rename a local variable
Date: Fri, 4 Sep 2020 21:16:09 -0400 (EDT)

branch: master
commit 4f10238d1b119410f764da633cafb4633d6abbf5
Author: Gregory W. Chicares <gchicares@sbcglobal.net>
Commit: Gregory W. Chicares <gchicares@sbcglobal.net>

    Rename a local variable
---
 ihs_avmly.cpp | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/ihs_avmly.cpp b/ihs_avmly.cpp
index 6c65ba4..9973c8a 100644
--- a/ihs_avmly.cpp
+++ b/ihs_avmly.cpp
@@ -989,12 +989,12 @@ void AccountValue::TxSpecAmtChange()
         ChangeSupplAmtBy(DeathBfts_->supplamt()[Year] - TermSpecAmt);
         }
 
-    double const YearsSpecAmt = DeathBfts_->specamt()[Year];
+    double const new_specamt = DeathBfts_->specamt()[Year];
     double const old_specamt = DeathBfts_->specamt()[Year - 1];
 
     // Nothing to do if no increase or decrease requested.
-    // TODO ?? YearsSpecAmt != ActualSpecAmt; the latter should be used.
-    if(YearsSpecAmt == old_specamt)
+    // TODO ?? new_specamt != ActualSpecAmt; the latter should be used.
+    if(new_specamt == old_specamt)
         {
         return;
         }
@@ -1002,7 +1002,7 @@ void AccountValue::TxSpecAmtChange()
     if
         (
             !AllowSAIncr
-        &&  ActualSpecAmt < YearsSpecAmt
+        &&  ActualSpecAmt < new_specamt
         )
         {
         alarum()
@@ -1015,7 +1015,7 @@ void AccountValue::TxSpecAmtChange()
     if
         (
             MaxIncrAge < Year + BasicValues::GetIssueAge()
-        &&  ActualSpecAmt < YearsSpecAmt
+        &&  ActualSpecAmt < new_specamt
         )
         {
         alarum()
@@ -1027,7 +1027,7 @@ void AccountValue::TxSpecAmtChange()
         return;
         }
 
-    ChangeSpecAmtBy(YearsSpecAmt - ActualSpecAmt);
+    ChangeSpecAmtBy(new_specamt - ActualSpecAmt);
 
     // TODO ?? TAXATION !! Should 7702 or 7702A processing be done here?
 }



reply via email to

[Prev in Thread] Current Thread [Next in Thread]